--[[
************************************************************************
Project				: Broker_HitCrit
Author				: zhinjio
Project Revision	: r9
Project Date		: 20081104111947

File				: HitCrit_Options.lua
Commit Author		: zhinjio
Commit Revision		: 9
Commit Date			: 20081104111947
************************************************************************
Description	:
	bliz/ace3 options functions 

TODO		:

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]
local MODNAME			= "HitCrit"
local addon				= LibStub("AceAddon-3.0"):GetAddon(MODNAME)

local L					= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local AceConfig 		= LibStub("AceConfig-3.0")
local AceConfigReg 		= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")

local addonversion = "r9"
local addonauthor = "zhinjio"
local builddate = "20081104111947"

local modularOptions = {}

local function giveTracking()
	if (not trackingOptions) then
		trackingOptions = {
			order = 2,
			type = "group",
			name = L["Tracking Options"],
			desc = L["TRACKING_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 21,
					type	= "header",
					name	= L["Tracking Options"],
				},
				desc = {
					order	= 22,
					type	= "description",
					name	= L["FILTERING_OPTIONS_DESC"],
				},
				pvp = {
					order	= 23,
					type	= "toggle",
					name	= L["Track PvP"],
					desc	= L["TRACK_PVP_DESC"],
					get		= function() return db.options.tracking.pvp end,
					set		= function() db.options.tracking.pvp = not db.options.tracking.pvp end,
				},
				againstMe = {
					order	= 24,
					type	= "toggle",
					name	= L["Track Hits Against Me"],
					desc	= L["TRACK_AGAINSTME_DESC"],
					get		= function() return db.options.tracking.againstMe end,
					set		= function() db.options.tracking.againstMe = not db.options.tracking.againstMe end,
					disabled = true,
				},
				damage = {
					order	= 25,
					type	= "toggle",
					name	= L["Track Damage"],
					desc	= L["TRACK_DAMAGE_DESC"],
					get		= function() return db.options.tracking.damage end,
					set		= function() db.options.tracking.damage = not db.options.tracking.damage end,
				},
				healing = {
					order	= 26,
					type	= "toggle",
					name	= L["Track Healing"],
					desc	= L["TRACK_HEALING_DESC"],
					get		= function() return db.options.tracking.healing end,
					set		= function() db.options.tracking.healing = not db.options.tracking.healing end,
				},
				environmental = {
					order	= 27,
					type	= "toggle",
					name	= L["Track Environmental"],
					desc	= L["TRACK_ENVIRONMENTAL_DESC"],
					get		= function() return db.options.tracking.environmental end,
					set		= function() db.options.tracking.environmental = not db.options.tracking.environmental end,
					disabled = true,
				},
				vulnerable = {
					order	= 28,
					type	= "toggle",
					name	= L["Track Vulnerable"],
					desc	= L["TRACK_VULNERABLE_DESC"],
					get		= function() return db.options.tracking.vulnerable end,
					set		= function() db.options.tracking.vulnerable = not db.options.tracking.vulnerable end,
					disabled = true,
				},
				lowlevel = {
					order	= 28,
					type	= "toggle",
					name	= L["Track Low Level"],
					desc	= L["TRACK_LOWLEVEL_DESC"],
					get		= function() return db.options.tracking.lowlevel end,
					set		= function() db.options.tracking.lowlevel = not db.options.tracking.lowlevel end,
					disabled = true,
				},
			},
		}
	end
end

local function giveDisplay()
	if (not displayOptions) then
		displayOptions = {
			order = 3,
			type = "group",
			name = L["Display Options"],
			desc = L["DISPLAY_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 31,
					type	= "header",
					name	= L["Display Options"],
				},
				desc = {
					order	= 32,
					type	= "description",
					name	= L["DISPLAY_OPTIONS_DESC"],
				},
				hit = {
					order	= 33,
					type	= "toggle",
					name	= L["Display Hit"],
					desc	= L["DISPLAY_HIT_DESC"],
					get		= function() return db.options.display.hit end,
					set		= function() db.options.display.hit = not db.options.display.hit end,
				},
				crit = {
					order	= 34,
					type	= "toggle",
					name	= L["Display Crit"],
					desc	= L["DISPLAY_CRIT_DESC"],
					get		= function() return db.options.display.crit end,
					set		= function() db.options.display.crit = not db.options.display.crit end,
				},
				enemyName = {
					order	= 35,
					type	= "toggle",
					name	= L["Display Enemy Name"],
					desc	= L["DISPLAY_ENEMYNAME_DESC"],
					get		= function() return db.options.display.enemyName end,
					set		= function() db.options.display.enemyName = not db.options.display.enemyName end,
				},
				school = {
					order	= 36,
					type	= "toggle",
					name	= L["Sort by School"],
					desc	= L["DISPLAY_SORTSCHOOL_DESC"],
					get		= function() return db.options.display.type end,
					set		= function() db.options.display.type = not db.options.display.type end,
				},
				fontsize = {
					order	= 37,
					type	= "select",
					name	= L["Font Size"],
					desc	= L["DISPLAY_FONTSIZE_DESC"],
					get		= function() return db.options.display.fontsize end,
					set		= function( info, name ) db.options.display.fontsize = name end,
					values	= function() return { Small = L["small"], Large = L["large"] } end
				},
			},
		}
	end
end

local function giveAlert()
	if (not alertOptions) then
		alertOptions = {
			order = 4,
			type = "group",
			name = L["Alert Options"],
			desc = L["ALERT_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 41,
					type	= "header",
					name	= L["Alert Options"],
				},
				desc = {
					order	= 42,
					type	= "description",
					name	= L["ALERT_OPTIONS_DESC"],
				},
				sound = {
					order	= 43,
					type	= "toggle",
					name	= L["Alert with Sound"],
					desc	= L["ALERT_SOUND_DESC"],
					get		= function() return db.options.alerts.sound end,
					set		= function() db.options.alerts.sound = not db.options.alerts.sound end,
				},
				notify = {
					order	= 44,
					type	= "toggle",
					name	= L["Alert with Notify"],
					desc	= L["ALERT_NOTIFY_DESC"],
					get		= function() return db.options.alerts.notify end,
					set		= function() db.options.alerts.notify = not db.options.alerts.notify end,
				},
				chatframe = {
					order	= 45,
					type	= "toggle",
					name	= L["Alert in Chat Frame"],
					desc	= L["ALERT_CHATFRAME_DESC"],
					get		= function() return db.options.alerts.chatframe end,
					set		= function() db.options.alerts.chatframe = not db.options.alerts.chatframe end,
				},
			},
		}
	end
end

local options = nil
local function fullOptions()
	if (not options) then
		options = {
			type = "group",
			name = MODNAME,
			args = {
				general = {
					order	= 1,
					type	= "group",
					name	= L["General Information"],
					desc	= L["GENERAL_INFO_DESC"],
					args	= {
						header1 = {
							order	= 11,
							type	= "header",
							name	= L["General Information"],
						},
						desc = {
							order	= 12,
							type	= "description",
							name	= L["GENERAL_INFO_DESC"],
						},
						author = {
							order	= 13,
							type	= "description",
							name	= L["Author : "] .. addonauthor .. "\n",
						},
						version = {
							order	= 14,
							type	= "description",
							name	= L["Version : "] .. addonversion .. "\n",
						},
						builddate = {
							order	= 15,
							type	= "description",
							name	= L["Build Date : "] .. addonauthor .. "\n",
						},
						dbversion = {
							order	= 15,
							type	= "description",
							name	= L["Database Version : "] .. db.options.display.dbVersion .. "\n",
						},
					},
				},
			},
		}
	end
	
	for k,v in pairs(modularOptions) do
		options.args[k] = (type(v) == "function") and v() or v
	end

	return options
end

function addon:SetupOptions()
	AceConfigReg:RegisterOptionsTable(MODNAME, fullOptions)
	self.optionsFrame = AceConfigDialog:AddToBlizOptions(MODNAME, nil, nil, "general")

	-- Fill up our modular options...
	self:RegisterModuleOptions("Tracking", giveTracking(), L["Tracking Options"])
	self:RegisterModuleOptions("Display", giveDisplay(), L["Display Options"])
	self:RegisterModuleOptions("Alert", giveAlert(), L["Alert Options"])
end

-- Description: Function which extends our options table in a modular way
-- Expected result: add a new modular options table to the modularOptions upvalue as well as the Blizzard config
-- Input:
--		name			: index of the options table in our main options table
--		optionsTable	: the sub-table to insert
--		displayName	: the name to display in the config interface for this set of options
-- Output: None.

function addon:RegisterModuleOptions(name, optionsTable, displayName)
	modularOptions[name] = optionsTable
	self.optionsFrame[name] = AceConfigDialog:AddToBlizOptions(MODNAME, displayName, MODNAME, name)
end

--[[
************************************************************************
CHANGELOG:

Date : 10/29/08
	Initial version. Thanks to Antiarc for the slick mechanism
************************************************************************
]]--